#############
API reference
#############

This page lists all available functions and classes of `skrub`.

.. toctree::
   :maxdepth: 2

   joining_dataframes
   encoding_a_column
   building_a_pipeline
   generating_a_report
   cleaning_a_dataframe
   downloading_a_dataset
